@@ -10,7 +10,7 @@ use Process::KillTree;
 
 our @EXPORT_OK = qw(kill_group);
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %SPEC;
 
@@ -33,7 +33,7 @@ Process::KillGroup - Kill process and all other belonging to the same process gr
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -46,12 +46,14 @@ version 0.02
 
 This module provides kill_group().
 
+=head1 SEE ALSO
+
+L<Process::KillTree>
+
 =head1 FUNCTIONS
 
-None are exported by default, but they are exportable.
-
-=head2 kill_group(%args) -> RESULT
 
+=head2 kill_group(%args) -> [status, msg, result, meta]
 
 Kill process and all other belonging to the same process group.
 
@@ -60,10 +62,7 @@ Linux. Croaks on other operating systems.
 
 Returns the killed PIDs.
 
-This function supports dry-run (simulation) mode. To run in dry-run mode, add
-argument C<-dry_run> => 1.
-
-Arguments (C<*> denotes required arguments):
+Arguments ('*' denotes required arguments):
 
 =over 4
 
@@ -85,15 +84,15 @@ Process IDs to kill.
 
 Either pid or pids must be specified
 
-=item * B<signal> => I<str> (default C<"TERM">)
+=item * B<signal> => I<str> (default: "TERM")
 
 Signal to use, either numeric (e.g. 1), or string (e.g. KILL).
 
 =back
 
-=head1 SEE ALSO
+Return value:
 
-L<Process::KillTree>
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
 
 =head1 AUTHOR
 
@@ -101,7 +100,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
